summaryrefslogtreecommitdiffstats
path: root/content/browser
diff options
context:
space:
mode:
authorasanka@chromium.org <asanka@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-08-09 13:38:55 +0000
committerasanka@chromium.org <asanka@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-08-09 13:38:55 +0000
commitbf3bff73c6adc84b49447ee9cffac24e0a63c1c7 (patch)
tree2cf1f0921e1009149b0d8bd5562aa268cdcee59e /content/browser
parentb7f526f6a6b5f81bb649dd2e77faa24a0b4afb39 (diff)
downloadchromium_src-bf3bff73c6adc84b49447ee9cffac24e0a63c1c7.zip
chromium_src-bf3bff73c6adc84b49447ee9cffac24e0a63c1c7.tar.gz
chromium_src-bf3bff73c6adc84b49447ee9cffac24e0a63c1c7.tar.bz2
[Download] Deprecate WRITE_SIZE_COUNT and WRITE_LOOP_COUNT UMA enums.
The Download.Counts histogram has two enum values, WRITE_SIZE_COUNT and WRITE_LOOP_COUNT that measure the number of samples recorded in the Download.WriteSize and Download.WriteLoopCount UMA histograms. This is a waste since the count of samples is readily available. In addition, these two counts exceed every other bucket in Download.Counts by ~4 orders of magnitude causing everything else to be normalized to ~0%. BUG=none Review URL: https://chromiumcodereview.appspot.com/22529003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@216682 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser')
-rw-r--r--content/browser/download/download_stats.cc2
-rw-r--r--content/browser/download/download_stats.h13
2 files changed, 8 insertions, 7 deletions
diff --git a/content/browser/download/download_stats.cc b/content/browser/download/download_stats.cc
index f8a1e09..7831a4d 100644
--- a/content/browser/download/download_stats.cc
+++ b/content/browser/download/download_stats.cc
@@ -168,13 +168,11 @@ void RecordDangerousDownloadDiscard(DownloadDiscardReason reason,
}
void RecordDownloadWriteSize(size_t data_len) {
- RecordDownloadCount(WRITE_SIZE_COUNT);
int max = 1024 * 1024; // One Megabyte.
UMA_HISTOGRAM_CUSTOM_COUNTS("Download.WriteSize", data_len, 1, max, 256);
}
void RecordDownloadWriteLoopCount(int count) {
- RecordDownloadCount(WRITE_LOOP_COUNT);
UMA_HISTOGRAM_ENUMERATION("Download.WriteLoopCount", count, 20);
}
diff --git a/content/browser/download/download_stats.h b/content/browser/download/download_stats.h
index be2ae4b..ebe643e 100644
--- a/content/browser/download/download_stats.h
+++ b/content/browser/download/download_stats.h
@@ -48,11 +48,14 @@ enum DownloadCountTypes {
// Downloads that were interrupted by the OS.
INTERRUPTED_COUNT,
- // Write sizes for downloads.
- WRITE_SIZE_COUNT,
-
- // Counts iterations of the BaseFile::AppendDataToFile() loop.
- WRITE_LOOP_COUNT,
+ // (Deprecated) Write sizes for downloads.
+ // This is equal to the number of samples in Download.WriteSize histogram.
+ DOWNLOAD_COUNT_UNUSED_10,
+
+ // (Deprecated) Counts iterations of the BaseFile::AppendDataToFile() loop.
+ // This is equal to the number of samples in Download.WriteLoopCount
+ // histogram.
+ DOWNLOAD_COUNT_UNUSED_11,
// Counts interruptions that happened at the end of the download.
INTERRUPTED_AT_END_COUNT,